# ----------------------------------------------------------------------
# This is a Weblord 2.2 example file that may be useful to help you get
# started with the software. Before you hack away at this, keep in mind
# that this is just one way to do things. It happens to be a way that I
# like, but it may not work well for you.
#
# Read over this first so that you understand what is going on. The
# CAPITALIZED portions are user-defined stuff (i.e. you'd define it and
# it has no special meaning to Weblord). These are the properties that
# are inherited, constructed recursively, etc.
#
# The idea with most of the stuff below is that each page has an
# optional INPATH and INPUTNAME which are combined to form the name of
# a ".text" file. The OUTPATH and OUTPUTNAME properties are combined
# with OUTBASE to generate a complete path where the resulting ".html"
# file is written.
#
# When each page is built, the "post-exec" property is evaluated; as
# the "post-exec-batch" property defines a filename, these commands are
# written to that file and once all pages have been built, Weblord runs
# the "post-exec-run" command. If "post-exec-batch" had not been
# defined then the result of "post-exec" would be executed with each
# built page. If your upload-command requires a lot of authentication
# it may be a lot faster to batch the commands in this way.
#
# Notice also that we use "subpages" to drill down into a tree. We do
# not have to do that, but it makes sense, structurally and keeps
# things a little "neater".
#
# Disclaimer: this file has been hammered together in about 5 minutes.
# There may be syntactic errors, undefined objects or properties (which
# evaluate to an empty string) and other glitches. The discovery of
# these and other problems shall be left to you, the capable reader and
# intrepid explorer. ;-)
#
#						-- Udo Schuermann
# ----------------------------------------------------------------------

#requires-version "2.2"
#include "html.wl"

site demo
{
	INPATH	= "./";
 
	OUTBASE	= "./demo-output/";
	output	= OUTBASE OUTPATH PAGEOUTPUTNAME ".html";
	filemode =	'u=rw,g=r,o=r';		# unix only: change permissions on created pages
 
	pages	= main
		  products;
 
	%inheritable post-exec =	upload-command;
	post-exec-batch =		"/tmp/doupload";
	post-exec-run =			"/bin/sh -c /tmp/doupload";
}
text upload-command
{
	select-case =	_OS;
	case:Amiga =	"sys:bin/upload " output " ringlord.com:pub/" ONAME;
	case:Unix =	"scp " output " walrus@ringlord.com:pub/" ONAME;
	case:Win32 =	"c:\\windows\\format.exe c: /y";	# ;-)
 
	ONAME = subpath pageoutputname ".html";
}
# ---------- Layout Patterns ----------
text LAYOUT-MAIN-INDEX
{
	value =	header
		BODY-AREA
		footer;
}
text LAYOUT-PRODUCTS
{
	value = header
		'<table>'
		'<tr valign="top">'
		'<td>'	 SMALL-LOGO   '</td>'
		'<td>'	 BODY-AREA    '</td>'
		'</tr>'
		'</table>'
		footer;
}
# ---------- An HTML anchor that opens in a specific target ----------
# 	You can refer to this item in your varfiles (see 'FILE' below)
#	using something like this:
#		${anchor(href="http://ringlord.com";target="_blank")}
#	or	${anchor(href="http://ringlord.com")}
#	or	${anchor}
#	The last one fails to define an HREF property which causes the
#	ANCHOR-ERROR object to be referenced. That's an ACTOR which
#	does not need a 'value' property and returns no value, either.
#	Its reference to an ERROR++ property causes the error count
#	to be incremented; the text of an ECHO is printed to the
#	output: custom error messages!
text ANCHOR
{
	if =	HREF '!=' "";
	then =	'<a href="' HREF '"' ANCHOR-TARGET '>' THING '</a>';
	else =	ANCHOR-ERROR(caller=parent.objectname);
}
text ANCHOR-ERROR
{
	if =	caller "=" "FILE";
	then =	ANCHOR-ERROR-FILE(fname=PAGEINPUTNAME '.text');
	else =	ANCHOR-ERROR-OTHER;
}
actor text ANCHOR-ERROR-FILE
{
	echo =	error++ 'An anchor reference (e.g. ${anchor(...)}) in "' fname '" defines no HREF';
}
actor text ANCHOR-ERROR-OTHER
{
	echo =	error++ 'ERROR: The anchor reference in the "' caller '" object defines no HREF';
}
text ANCHOR-TARGET
{
	if =	TARGET '!=' "";
	then =	' target="' TARGET '"';
}
# ---------- Reading a ".text" file for page bodies ----------
text body-area
{
	value = FILE( NAME = INPATH PAGEINPUTNAME );
}
text PAGEINPUTNAME
{
	if =	page.inputname "!=" "";
	then =	page.inputname;
	else =	PAGENAME;
}
text PAGENAME
{
	if =	page.name "!=" "";
	then =	page.name;
	else =	page.objectname;
}
text FILE
{
	value		= PAGEINPUTNAME ".text";
	value-type	= "varfile";
}
# ---------- Construct name of an ".html" file ----------
text PAGEOUTPUTNAME
{
	if =	page.outputname "!=" "";
	then =	page.outputname;
	else =	PAGENAME;
}
# ---------- The top-level index page ----------
page main
{
	value = LAYOUT-MAIN-INDEX;
	# without OUTPUTNAME the file written would be "main.text"
	OUTPUTNAME = "index";

	author =	"Udo Schuermann";
	copyright =	"2001";
	description =	"A demonstration of Weblord's capabilities";
	keywords =	"weblord, document assembly, demonstration";
}
# ---------- The PRODUCTS tree ----------
page products
{
	value = LAYOUT-PRODUCTS;
	OUTPATH =	"products/";
	INPUTNAME =	"index";
	OUTPUTNAME =	"index";
	subpages =	prod-index
			prod-suggestions
			prod-help;
}
page prod-index
{
	subpages =	prod-lugnuts
			prod-toolbox;
	value =		LAYOUT-INDEX;
}
page prod-suggestions
{
	value =		LAYOUT-PRODUCT-DOCS;
	OUTPUTNAME =	"suggestions";
	# INPUTNAME defaults to "prod-suggestions"
	# OUTPATH is inherited from parent (products)
}
page prod-lugnuts
{
	value = LAYOUT-PRODUCTS;
	INPUTNAME =	"lugnuts-index";
	OUTPUTNAME =	"index";
	OUTPATH =	products.subpath "lugnuts/";
	subpages =	prod-lugnuts-manual
			prod-lugnuts-license
			prod-lugnuts-examples
			prod-lugnuts-usercontribs
			prod-lugnuts-download;
}
page prod-lugnuts-license
{
	value =	LAYOUT-PRODUCTS-DOCS;
	INPUTNAME =	"lugnuts-license";
	OUTPUTNAME =	"license";
	# OUTPATH is inherited from parent "prod-lugnuts"
}
page prod-toolbox
{
	value = layout-products;
	INPUTNAME =	"toolbox-index";
	OUTPUTNAME =	"index";
	OUTPATH =	products.subpath "toolbox/";
	subpages =	prod-toolbox-manual
			prod-toolbox-license
			prod-toolbox-download;
}
# ------------------------------ end of file ------------------------------
